# SQLiteManager
Has a Database, Table and Record object to easily manipulate SQLite storage

## Version
### 0.1


## Install
```
pip install sqlitemanager
```

## Import
### Directly usable
import the directly usable objects
```
from sqlitemanager import Database
from sqlitemanager import Table
from sqlitemanager import Record
```

### Generic Database class

## How to

```

```

## Licence

Licensed under GPL-3.0-or-later, see LICENSE file for details.

Copyright © 2020 Michael-Yongshi.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.
